/*
 * Target.java
 *
 * Created on 12 July 2007, 10:21
 */

package archery;
import javax.swing.*;
import java.awt.*;
/**
 *
 * @author  christopher
 */
public class Target extends javax.swing.JPanel {
    
    //global variables
    int centreX = 0;
    int centreY = 0;
    int width = 0;
    int height = 0;
    int diameter = 0;
    
    private boolean zoom = false;
    int shot = 0;
    int end;
    
    //Public Variables
    public int scoreCount = 0;
    int[][] scores = new int[30][7];
    
    //position is an array in which the first dimension gives the shot number.
    //the information contained within the second dimension is as follows:
    //[0] = x position
    //[1] = y position
    //[2] = distance shot.
    private int[][] position = new int[500][3];
    
    /** Creates new form Target */
    public Target() {        
        initComponents();             
    }
    
    /**Sets the zoom of the target face*
    *@param zoom whether you want to zoom in (true) or out (false)*/
    public void setZoom(boolean zoom) {
        this.zoom = zoom;
    }
    
    /**Clears all scoring information for this round.  Information already submitted
     *to the score tables remains intact.
     */     
    public void clearAll() {
        repaint();
        scoreCount = 0;        
        for(int i = 0; i < scores[end].length; i++)
            scores[end][i] = 0;  
        jLabel3.setText("-");
        position[shot][0] = 0;
        position[shot][1] = 0;
        position[shot][2] = ArcheryUI.tab.getDistance();
    }
    
    public void done() {
        repaint();
        scoreCount = 0;
        jLabel3.setText("-");        
    }
    
    /**Tells the target to move on to the next end*/
    public void addEnd() {
        end++;
    }
    
    /**Returns the current end
     *@return end the current end*/
    public int getEnd() {
        return end;        
    }
    /**Returns an array containing the scores for the round
     *@return scores[]
     **/
    public int[][] getScores() {
        return scores;
    }
    
    public int[][] getPosition() {
        return position;
    }
    
    /**paints all the shots recorded to the target face
     * this is a clever piece of code, because it figures out whether you're
     * zoomed in or not and paints your arrows in the right place!
     * a triumph if I do say so myself! Took a while to do too!**/
    public void paintShots(int[][] pos) {
        int[][] pos2 = pos;
        int centreX = getWidth()/2;
        int centreY = getHeight()/2;       
        
        Graphics g = getGraphics();
        g.setColor(Color.GREEN);
        if(zoom == false) {
            for(int i = 0; i < pos2.length; i++) {            
            g.fillOval(pos2[i][0] - 2, pos2[i][1] - 2, 4, 4);
            } 
        }
        else if(zoom == true) {
            for(int i = 0; i < pos2.length; i++) {
                int xFC = pos2[i][0] - centreX;
                int yFC = pos2[i][1] - centreY;
                int xFC2 = xFC*2;
                int yFC2 = yFC*2;                
                g.fillOval(xFC2 + centreX, yFC2 + centreY, 4, 4);
            }
        }
                   
    }
    
    /**Standard method for drawing on JPanels.  This one has been altered so 
     * it draws a target face.  Code is included to draw the face zoomed in and out**/
    public void paintComponent(Graphics g) {
        super.paintComponent(g);        
        centreX = getWidth()/2;
        centreY = getHeight()/2;
        width = getWidth();
        height = getHeight();    
        
        if(height > width) {
            diameter = width;
        }
        else diameter = height;
        
        if(zoom == false) {
            //Code for drawing the target face zoomed out
            g.setColor(Color.white);
            g.fillOval(centreX - diameter/2, centreY - diameter/2, diameter , diameter);
            g.setColor(Color.black);
            g.fillOval(centreX - ((diameter * 8/10)/2), centreY - ((diameter * 8/10)/2), diameter * 8/10, diameter * 8/10);
            g.setColor(Color.blue);
            g.fillOval(centreX - ((diameter * 6/10)/2), centreY - ((diameter * 6/10)/2), diameter * 6/10, diameter * 6/10);
            g.setColor(Color.red);
            g.fillOval(centreX - ((diameter * 4/10)/2), centreY - ((diameter * 4/10)/2), diameter * 4/10, diameter * 4/10);
            g.setColor(Color.yellow);
            g.fillOval(centreX - ((diameter * 2/10)/2), centreY - ((diameter * 2/10)/2), diameter * 2/10, diameter * 2/10);
            g.setColor(Color.black);
            g.drawOval(centreX - ((diameter * 1/10)/2), centreY - ((diameter * 1/10)/2), diameter * 1/10, diameter * 1/10);
            g.drawOval(centreX - ((diameter * 2/10)/2), centreY - ((diameter * 2/10)/2), diameter * 2/10, diameter * 2/10);
            g.drawOval(centreX - ((diameter * 3/10)/2), centreY - ((diameter * 3/10)/2), diameter * 3/10, diameter * 3/10);
            g.drawOval(centreX - ((diameter * 4/10)/2), centreY - ((diameter * 4/10)/2), diameter * 4/10, diameter * 4/10);
            g.drawOval(centreX - ((diameter * 5/10)/2), centreY - ((diameter * 5/10)/2), diameter * 5/10, diameter * 5/10);
            g.drawOval(centreX - ((diameter * 6/10)/2), centreY - ((diameter * 6/10)/2), diameter * 6/10, diameter * 6/10);
            g.setColor(Color.white);
            g.drawOval(centreX - ((diameter * 7/10)/2), centreY - ((diameter * 7/10)/2), diameter * 7/10, diameter * 7/10);        
            g.drawOval(centreX - ((diameter * 8/10)/2), centreY - ((diameter * 8/10)/2), diameter * 8/10, diameter * 8/10);
            g.setColor(Color.black);
            g.drawOval(centreX - ((diameter * 9/10)/2), centreY - ((diameter * 9/10)/2), diameter * 9/10, diameter * 9/10);
            g.drawOval(centreX - diameter/2, centreY - diameter/2, diameter-1 , diameter-1);
        }
        else {
             //Code for drawing the target Face zoomed in.
        g.setColor(Color.blue);
        g.fillOval(centreX - (diameter/2), centreY - (diameter/2), diameter , diameter);
        g.setColor(Color.red);
        g.fillOval(centreX - ((diameter * 8/10)/2), centreY - ((diameter * 8/10)/2), diameter * 8/10, diameter * 8/10);
        g.setColor(Color.yellow);
        g.fillOval(centreX - ((diameter * 4/10)/2), centreY - ((diameter * 4/10)/2), diameter * 4/10, diameter * 4/10);
        g.setColor(Color.black);
        g.drawOval(centreX - diameter/2, centreY - diameter/2, diameter-1 , diameter-1);   
        g.drawOval(centreX - ((diameter * 1/20)/2), centreY - ((diameter * 1/20)/2), diameter * 1/20, diameter * 1/20);
        g.drawOval(centreX - ((diameter * 2/10)/2), centreY - ((diameter * 2/10)/2), diameter * 2/10, diameter * 2/10);
        g.drawOval(centreX - ((diameter * 4/10)/2), centreY - ((diameter * 4/10)/2), diameter * 4/10, diameter * 4/10);
        g.drawOval(centreX - ((diameter * 6/10)/2), centreY - ((diameter * 6/10)/2), diameter * 6/10, diameter * 6/10);
        g.drawOval(centreX - ((diameter * 8/10)/2), centreY - ((diameter * 8/10)/2), diameter * 8/10, diameter * 8/10);
        }
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        jLabel3 = new javax.swing.JLabel();
        zoomIn = new javax.swing.JButton();
        zoomOut = new javax.swing.JButton();

        addMouseListener(new java.awt.event.MouseAdapter() {
            public void mouseClicked(java.awt.event.MouseEvent evt) {
                formMouseClicked(evt);
            }
        });

        jLabel3.setText("-");

        zoomIn.setText("+");
        zoomIn.setToolTipText(" zoom in");
        zoomIn.setBorder(null);
        zoomIn.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                zoomInActionPerformed(evt);
            }
        });

        zoomOut.setText("-");
        zoomOut.setToolTipText("zoom out");
        zoomOut.setBorder(null);
        zoomOut.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                zoomOutActionPerformed(evt);
            }
        });

        org.jdesktop.layout.GroupLayout layout = new org.jdesktop.layout.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(layout.createSequentialGroup()
                .addContainerGap()
                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
                    .add(org.jdesktop.layout.GroupLayout.TRAILING, layout.createSequentialGroup()
                        .add(zoomIn, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 25, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE)
                        .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 142, Short.MAX_VALUE)
                        .add(zoomOut))
                    .add(org.jdesktop.layout.GroupLayout.TRAILING, jLabel3))
                .addContainerGap())
        );

        layout.linkSize(new java.awt.Component[] {zoomIn, zoomOut}, org.jdesktop.layout.GroupLayout.HORIZONTAL);

        layout.setVerticalGroup(
            layout.createParallelGroup(org.jdesktop.layout.GroupLayout.LEADING)
            .add(layout.createSequentialGroup()
                .addContainerGap()
                .add(layout.createParallelGroup(org.jdesktop.layout.GroupLayout.BASELINE)
                    .add(zoomOut)
                    .add(zoomIn, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE, 19, org.jdesktop.layout.GroupLayout.PREFERRED_SIZE))
                .addPreferredGap(org.jdesktop.layout.LayoutStyle.RELATED, 245, Short.MAX_VALUE)
                .add(jLabel3)
                .addContainerGap())
        );

        layout.linkSize(new java.awt.Component[] {zoomIn, zoomOut}, org.jdesktop.layout.GroupLayout.VERTICAL);

    }// </editor-fold>//GEN-END:initComponents

    private void zoomOutActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_zoomOutActionPerformed
        if(zoom == true) {
            zoom = false;
            repaint();
        }
    }//GEN-LAST:event_zoomOutActionPerformed

    private void zoomInActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_zoomInActionPerformed
        if(zoom == false) {
            zoom = true;
            repaint();
        }
    }//GEN-LAST:event_zoomInActionPerformed

   /**The scoring code for the target face**/
    private void formMouseClicked(java.awt.event.MouseEvent evt) {//GEN-FIRST:event_formMouseClicked
        int x = evt.getX() - centreX;
        int y = evt.getY() - centreY;
        int xAbsolute = evt.getX();
        int yAbsolute = evt.getY();
        int x2 = x*x;
        int y2 = y*y;
        
        if(scoreCount < 6) {
        Graphics g = getGraphics();
        g.setColor(Color.GREEN);
        g.fillOval(evt.getX() - 2, evt.getY() - 2, 4, 4);    
        scoreCount++;
        
        if(zoom == false && ArcheryUI.tab.isMetric() == true) {
            //Section that determines what score each click is, on zoomed out
            //mode for a metric round:
            if((x2 + y2) <= ((diameter * 1/20) * (diameter * 1/20))) {
                jLabel3.setText("" + 10);
                scores[end][scoreCount] = 10;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
           }
            else if((x2 + y2) <= ((diameter * 2/20) * (diameter * 2/20))) {
                jLabel3.setText("" + 9);
                scores[end][scoreCount] = 9;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 3/20) * (diameter * 3/20))) {
                jLabel3.setText("" + 8);
                scores[end][scoreCount] = 8;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 4/20) * (diameter * 4/20))) {
                jLabel3.setText("" + 7);
                scores[end][scoreCount] = 7;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 5/20) * (diameter * 5/20))) {
                jLabel3.setText("" + 6);
                scores[end][scoreCount] = 6;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 6/20) * (diameter * 6/20))) {
                jLabel3.setText("" + 5);
                scores[end][scoreCount] = 5;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
                
            }
            else if((x2 + y2) <= ((diameter * 7/20) * (diameter * 7/20))) {
                jLabel3.setText("" + 4);
                scores[end][scoreCount] = 4;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
           }
            else if((x2 + y2) <= ((diameter * 8/20) * (diameter * 8/20))) {
                jLabel3.setText("" + 3);
                scores[end][scoreCount] = 3;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 9/20) * (diameter * 9/20))) {
                jLabel3.setText("" + 2);
                scores[end][scoreCount] = 2;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 10/20) * (diameter * 10/20))) {
                jLabel3.setText("" + 1);
                scores[end][scoreCount] = 1;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else {
                jLabel3.setText("" + 0);
                scores[end][scoreCount] = 0;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            shot++;
        }           
        
        //scoring code if zoomed in for a metric round
        else if(zoom == true && ArcheryUI.tab.isMetric() == true) {
            
            int xFromCentre = xAbsolute - centreX;
            int xFC2 = xFromCentre/2;            
            int yFromCentre = yAbsolute - centreY;
            int yFC2 = yFromCentre/2;
            
            if((x2 + y2) <= ((diameter * 2/20) * (diameter * 2/20))) {
                jLabel3.setText("" + 10);
                scores[end][scoreCount] = 10;
                position[shot][0] = xFC2 + centreX;
                position[shot][1] = yFC2 + centreY;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 4/20) * (diameter * 4/20))) {
                jLabel3.setText("" + 9);
                scores[end][scoreCount] = 9;
                position[shot][0] = xFC2 + centreX;
                position[shot][1] = yFC2 + centreY;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 6/20) * (diameter * 6/20))) {
                jLabel3.setText("" + 8);
                scores[end][scoreCount] = 8;
                position[shot][0] = xFC2 + centreX;
                position[shot][1] = yFC2 + centreY;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 8/20) * (diameter * 8/20))) {
                jLabel3.setText("" + 7);
                scores[end][scoreCount] = 7;
                position[shot][0] = xFC2 + centreX;
                position[shot][1] = yFC2 + centreY;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 10/20) * (diameter * 10/20))) {
                jLabel3.setText("" + 6);
                scores[end][scoreCount] = 6;     
                position[shot][0] = xFC2 + centreX;
                position[shot][1] = yFC2 + centreY;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            shot++;
        }
        
        //Scoring code for imperial targets when zoomed out
        else if(zoom == false && ArcheryUI.tab.isMetric() == false) {            
            //Section that determines what score each click is, on zoomed out
            //mode for a metric round:
            if((x2 + y2) <= ((diameter * 1/20) * (diameter * 1/20))) {
                jLabel3.setText("" + 9);
                scores[end][scoreCount] = 9;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
           }
            else if((x2 + y2) <= ((diameter * 2/20) * (diameter * 2/20))) {
                jLabel3.setText("" + 9);
                scores[end][scoreCount] = 9;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 3/20) * (diameter * 3/20))) {
                jLabel3.setText("" + 7);
                scores[end][scoreCount] = 7;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 4/20) * (diameter * 4/20))) {
                jLabel3.setText("" + 7);
                scores[end][scoreCount] = 7;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 5/20) * (diameter * 5/20))) {
                jLabel3.setText("" + 5);
                scores[end][scoreCount] = 5;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 6/20) * (diameter * 6/20))) {
                jLabel3.setText("" + 5);
                scores[end][scoreCount] = 5;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 7/20) * (diameter * 7/20))) {
                jLabel3.setText("" + 3);
                scores[end][scoreCount] = 3;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
           }
            else if((x2 + y2) <= ((diameter * 8/20) * (diameter * 8/20))) {
                jLabel3.setText("" + 3);
                scores[end][scoreCount] = 3;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 9/20) * (diameter * 9/20))) {
                jLabel3.setText("" + 1);
                scores[end][scoreCount] = 1;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 10/20) * (diameter * 10/20))) {
                jLabel3.setText("" + 1);
                scores[end][scoreCount] = 1;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else {
                jLabel3.setText("" + 0);
                scores[end][scoreCount] = 0;
                position[shot][0] = xAbsolute;
                position[shot][1] = yAbsolute;
                position[shot][2] = ArcheryUI.tab.getDistance();                
            }
            shot++;            
        }
        
        //Code for scoring an imperial target that is zoomed in
        else if(zoom == true && ArcheryUI.tab.isMetric() == false) {
            
            int xFromCentre = xAbsolute - centreX;
            int xFC2 = xFromCentre/2;            
            int yFromCentre = yAbsolute - centreY;
            int yFC2 = yFromCentre/2;
            
            if((x2 + y2) <= ((diameter * 2/20) * (diameter * 2/20))) {
                jLabel3.setText("" + 9);
                scores[end][scoreCount] = 9;
                position[shot][0] = xFC2 + centreX;
                position[shot][1] = yFC2 + centreY;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 4/20) * (diameter * 4/20))) {
                jLabel3.setText("" + 9);
                scores[end][scoreCount] = 9;
                position[shot][0] = xFC2 + centreX;
                position[shot][1] = yFC2 + centreY;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 6/20) * (diameter * 6/20))) {
                jLabel3.setText("" + 7);
                scores[end][scoreCount] = 7;
                position[shot][0] = xFC2 + centreX;
                position[shot][1] = yFC2 + centreY;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 8/20) * (diameter * 8/20))) {
                jLabel3.setText("" + 7);
                scores[end][scoreCount] = 7;
                position[shot][0] = xFC2 + centreX;
                position[shot][1] = yFC2 + centreY;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            else if((x2 + y2) <= ((diameter * 10/20) * (diameter * 10/20))) {
                jLabel3.setText("" + 5);
                scores[end][scoreCount] = 5;     
                position[shot][0] = xFC2 + centreX;
                position[shot][1] = yFC2 + centreY;
                position[shot][2] = ArcheryUI.tab.getDistance();
            }
            shot++;
        }
        }
        else { jLabel3.setText("Click 'Done' to submit score"); }
    }//GEN-LAST:event_formMouseClicked
    
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel jLabel3;
    private javax.swing.JButton zoomIn;
    private javax.swing.JButton zoomOut;
    // End of variables declaration//GEN-END:variables
    
}
